@@ -202,6 +202,13 @@ search_utmp(user, tty, mytty, myuid)
 				continue;	/* don't write to yourself */
 			}
 			++nttys;
+			/* if this is a newly created tty (eg fresh
+			 * xterm), then user will not have typed at
+			 * it, and the atime will be way in the
+			 * past. So, if the atime is < utmp creation
+			 * time, use the utmp time. */
+			if (atime < u.ut_time)
+			    atime = u.ut_time;
 			if (atime > bestatime) {
 				bestatime = atime;
 				(void)strcpy(tty, atty);
